@@ -13,8 +13,8 @@
 //! <br>
 //!
 //! Huh?
-//! - Imagine you are writing this cool API and want everyone to use it.
-//! - Everyone else, however, is running Unity, C, Python, ...
+//! - You wrote this cool Rust library and want everyone else to use it.
+//! - But everyone else runs Unity, C, Python, ...
 //! - "Not a problem", you say, "I'll just use Interoptopus".
 //!
 //! And you'll live happily<sup>*</sup> ever after.
@@ -131,7 +131,7 @@
 pub use error::Error;
 #[cfg(feature = "derive")]
 #[cfg_attr(docsrs, doc(cfg(feature = "derive")))] // does this work?
-pub use interoptopus_proc::{ffi_constant, ffi_function, ffi_type};
+pub use interoptopus_proc::{ffi_constant, ffi_function, ffi_service, ffi_service_ctor, ffi_service_method, ffi_type};
 
 pub use crate::core::{merge_libraries, Library};
 pub use generators::Interop;
@@ -266,7 +266,7 @@ macro_rules! inventory {
             let mut patterns: ::std::vec::Vec<$crate::patterns::LibraryPattern> = ::std::vec::Vec::new();
             $(
                 {
-                    let pattern: $crate::patterns::LibraryPattern = $pattern().into();
+                    let pattern: $crate::patterns::LibraryPattern = < $pattern as  $crate::patterns::LibraryPatternInfo>::pattern_info();
 
                     match &pattern {
                         $crate::patterns::LibraryPattern::Service(class) => {
